@@ -1,65 +1,5 @@
 var NAVTREEINDEX44 =
 {
-"complex__to__magphase__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,26,0],
-"complex__to__magphase__pydoc__template_8h.html#ac2cf29a98d0569f5e526fdede883a3dd":[7,0,9,2,0,0,0,26,2],
-"complex__to__magphase__pydoc__template_8h.html#ad842bb592d000e0d971b916a857b9c1d":[7,0,9,2,0,0,0,26,1],
-"complex__to__magphase__pydoc__template_8h.html#af11384ef5f59181a12ec2e77f3b3d1d1":[7,0,9,2,0,0,0,26,3],
-"complex__to__magphase__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,26],
-"complex__to__real_8h.html":[7,0,9,1,0,0,30],
-"complex__to__real_8h_source.html":[7,0,9,1,0,0,30],
-"complex__to__real__pydoc__template_8h.html":[7,0,9,2,0,0,0,27],
-"complex__to__real__pydoc__template_8h.html#a08560a02e2315987aec0ee947002e6ba":[7,0,9,2,0,0,0,27,2],
-"complex__to__real__pydoc__template_8h.html#a30b710f4067da429c21fc01c397a75a8":[7,0,9,2,0,0,0,27,3],
-"complex__to__real__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,27,0],
-"complex__to__real__pydoc__template_8h.html#afae7362c0deff9c7ad25e3ec39d377b4":[7,0,9,2,0,0,0,27,1],
-"complex__to__real__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,27],
-"config_8h.html":[7,0,2,0,0,0],
-"config_8h.html#a66a4d21d66fdd0e71f4158e68659aeb9":[7,0,2,0,0,0,1],
-"config_8h.html#a6b6efe280d35794d5a530c619f32fedd":[7,0,2,0,0,0,5],
-"config_8h.html#a7141d07920883c03580157e4e03fed42":[7,0,2,0,0,0,0],
-"config_8h.html#a7457af07cebb678e24f1a2f92858f028":[7,0,2,0,0,0,4],
-"config_8h.html#a9d642d742efafd3ebf92667f44b4520b":[7,0,2,0,0,0,3],
-"config_8h.html#aa1d9032f84a84242d1cc0ccd45430ae4":[7,0,2,0,0,0,2],
-"config_8h.html#adc9208b77af7662b249fffddf1e80f05":[7,0,2,0,0,0,6],
-"config_8h_source.html":[7,0,2,0,0,0],
-"conjugate__cc_8h.html":[7,0,9,1,0,0,31],
-"conjugate__cc_8h_source.html":[7,0,9,1,0,0,31],
-"conjugate__cc__pydoc__template_8h.html":[7,0,9,2,0,0,0,28],
-"conjugate__cc__pydoc__template_8h.html#a6e8adf4dbe8c9214eb46c0f8f974ad60":[7,0,9,2,0,0,0,28,3],
-"conjugate__cc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,28,0],
-"conjugate__cc__pydoc__template_8h.html#aaba8378b4765941793a82505ed345e48":[7,0,9,2,0,0,0,28,2],
-"conjugate__cc__pydoc__template_8h.html#afa9fc3a0c1b9fe94a0cc1d1bb56edf41":[7,0,9,2,0,0,0,28,1],
-"conjugate__cc__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,28],
-"const__sink__c_8h.html":[7,0,29,1,0,0,2],
-"const__sink__c_8h_source.html":[7,0,29,1,0,0,2],
-"const__sink__c__pydoc__template_8h.html":[7,0,29,2,0,0,0,1],
-"const__sink__c__pydoc__template_8h.html#a08c1a1bb3be9e004d96dbdec91c85a46":[7,0,29,2,0,0,0,1,5],
-"const__sink__c__pydoc__template_8h.html#a0bf32a9c68239c6e6150e7add1e33f71":[7,0,29,2,0,0,0,1,1],
-"const__sink__c__pydoc__template_8h.html#a152296613cd52a106de1331807603664":[7,0,29,2,0,0,0,1,6],
-"const__sink__c__pydoc__template_8h.html#a191a325a8806b9060fbd61a33e7587ab":[7,0,29,2,0,0,0,1,25],
-"const__sink__c__pydoc__template_8h.html#a1eef45a7787438f766ba22482af9252a":[7,0,29,2,0,0,0,1,13],
-"const__sink__c__pydoc__template_8h.html#a202fc3dbff9e1b2b687932db226b223d":[7,0,29,2,0,0,0,1,27],
-"const__sink__c__pydoc__template_8h.html#a23d60c57ee921f8f9491fa58690ede5b":[7,0,29,2,0,0,0,1,28],
-"const__sink__c__pydoc__template_8h.html#a2f5ebecd6ae0b82491b94652778414af":[7,0,29,2,0,0,0,1,30],
-"const__sink__c__pydoc__template_8h.html#a30ad767386a14502dfb7420063a1b5f3":[7,0,29,2,0,0,0,1,33],
-"const__sink__c__pydoc__template_8h.html#a396bb213ba5590554b79b0fdce7d15a8":[7,0,29,2,0,0,0,1,14],
-"const__sink__c__pydoc__template_8h.html#a609aa251cdcb0da5d8594ca93883d95e":[7,0,29,2,0,0,0,1,17],
-"const__sink__c__pydoc__template_8h.html#a69c12fc283bd34cae61c0b7904cc5384":[7,0,29,2,0,0,0,1,11],
-"const__sink__c__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,29,2,0,0,0,1,0],
-"const__sink__c__pydoc__template_8h.html#a74a970685c74bf8aecfc2451befb0b16":[7,0,29,2,0,0,0,1,29],
-"const__sink__c__pydoc__template_8h.html#a7abc56dbbe21b2f37366ba621c9ee0ac":[7,0,29,2,0,0,0,1,9],
-"const__sink__c__pydoc__template_8h.html#a7d968c546665f70ca84a71c4179ddcd9":[7,0,29,2,0,0,0,1,7],
-"const__sink__c__pydoc__template_8h.html#a89bc733e64675a8f448f705399ba1c47":[7,0,29,2,0,0,0,1,16],
-"const__sink__c__pydoc__template_8h.html#a9196c03e7145bd12e03a9f4543399215":[7,0,29,2,0,0,0,1,12],
-"const__sink__c__pydoc__template_8h.html#aa17781492606235d78fa006068b322ea":[7,0,29,2,0,0,0,1,32],
-"const__sink__c__pydoc__template_8h.html#aa61d235a2a4fd95188073e7d0f2cdfa6":[7,0,29,2,0,0,0,1,24],
-"const__sink__c__pydoc__template_8h.html#aa750b0fd988c1def5511748295b08bcf":[7,0,29,2,0,0,0,1,18],
-"const__sink__c__pydoc__template_8h.html#ab1182230b61ad1e1fa77f0bd95ff54c8":[7,0,29,2,0,0,0,1,20],
-"const__sink__c__pydoc__template_8h.html#ab98e7dbb114874bf01b895ba1a623b66":[7,0,29,2,0,0,0,1,15],
-"const__sink__c__pydoc__template_8h.html#ab9a0bca4f4eac989d2a81fd63eac6f8d":[7,0,29,2,0,0,0,1,3],
-"const__sink__c__pydoc__template_8h.html#acfbbb456194af45fc69868d53eb9c975":[7,0,29,2,0,0,0,1,19],
-"const__sink__c__pydoc__template_8h.html#adbf9687a38a30b9113c04abe8a3f0552":[7,0,29,2,0,0,0,1,21],
-"const__sink__c__pydoc__template_8h.html#adc70137698d2659397a052da26d004a6":[7,0,29,2,0,0,0,1,23],
 "const__sink__c__pydoc__template_8h.html#adfffa9b9a797c17acd4451d9d394b4b2":[7,0,29,2,0,0,0,1,10],
 "const__sink__c__pydoc__template_8h.html#ae0576729944b6a0383539d6e7487cf34":[7,0,29,2,0,0,0,1,8],
 "const__sink__c__pydoc__template_8h.html#aeb21b6e5b1eefa821d180ae27b12bf5a":[7,0,29,2,0,0,0,1,4],
@@ -249,5 +189,65 @@ var NAVTREEINDEX44 =
 "conv__bit__corr__bb_8h_source.html":[7,0,17,1,0,0,11],
 "conv__bit__corr__bb__pydoc__template_8h.html":[7,0,17,2,0,0,0,6],
 "conv__bit__corr__bb__pydoc__template_8h.html#a2519df3679698aa32727f13422dda568":[7,0,17,2,0,0,0,6,5],
-"conv__bit__corr__bb__pydoc__template_8h.html#a44b97efc7be9a385928897391bd9bcc4":[7,0,17,2,0,0,0,6,2]
+"conv__bit__corr__bb__pydoc__template_8h.html#a44b97efc7be9a385928897391bd9bcc4":[7,0,17,2,0,0,0,6,2],
+"conv__bit__corr__bb__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,17,2,0,0,0,6,0],
+"conv__bit__corr__bb__pydoc__template_8h.html#aeab5c28fa0627570e16cd23012edaea8":[7,0,17,2,0,0,0,6,3],
+"conv__bit__corr__bb__pydoc__template_8h.html#af314f7b9b7762a29126cf04dd6daeae1":[7,0,17,2,0,0,0,6,4],
+"conv__bit__corr__bb__pydoc__template_8h.html#aff32c9e5a06ce2cdac5dffd6a4b20ac6":[7,0,17,2,0,0,0,6,1],
+"conv__bit__corr__bb__pydoc__template_8h_source.html":[7,0,17,2,0,0,0,6],
+"copy_8h.html":[7,0,9,1,0,0,33],
+"copy_8h_source.html":[7,0,9,1,0,0,33],
+"copy__pydoc__template_8h.html":[7,0,9,2,0,0,0,30],
+"copy__pydoc__template_8h.html#a4e38abb6eff369e33d06369e0912534a":[7,0,9,2,0,0,0,30,5],
+"copy__pydoc__template_8h.html#a6a5c7d9f425103453f6555013e734ef8":[7,0,9,2,0,0,0,30,4],
+"copy__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,30,0],
+"copy__pydoc__template_8h.html#a8714300d6bdb1f62bb9e41d7683e14b2":[7,0,9,2,0,0,0,30,6],
+"copy__pydoc__template_8h.html#a9a03a1c544249f11260fcbebd9842e10":[7,0,9,2,0,0,0,30,1],
+"copy__pydoc__template_8h.html#ad997eb3d7e3725fb4a659c1fb2b50caa":[7,0,9,2,0,0,0,30,3],
+"copy__pydoc__template_8h.html#ae3014055c1bdeb8c21ef8658a76f1e42":[7,0,9,2,0,0,0,30,2],
+"copy__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,30],
+"core__algorithms_8h.html":[7,0,32,0,0,0,4],
+"core__algorithms_8h_source.html":[7,0,32,0,0,0,4],
+"core__algorithms__pydoc__template_8h.html":[7,0,32,1,0,0,0,3],
+"core__algorithms__pydoc__template_8h.html#a61565db3cffafadaf2b18056369faead":[7,0,32,1,0,0,0,3,1],
+"core__algorithms__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,32,1,0,0,0,3,0],
+"core__algorithms__pydoc__template_8h.html#aa25aa41e472da2f1239623f431a0ca42":[7,0,32,1,0,0,0,3,2],
+"core__algorithms__pydoc__template_8h.html#ace85748ddddb93c93f95aad6f3d84533":[7,0,32,1,0,0,0,3,3],
+"core__algorithms__pydoc__template_8h_source.html":[7,0,32,1,0,0,0,3],
+"corr__est__cc_8h.html":[7,0,13,1,0,0,17],
+"corr__est__cc_8h_source.html":[7,0,13,1,0,0,17],
+"corr__est__cc__pydoc__template_8h.html":[7,0,13,2,0,0,0,15],
+"corr__est__cc__pydoc__template_8h.html#a0a20e6c81fa2da1584327af8e6345767":[7,0,13,2,0,0,0,15,4],
+"corr__est__cc__pydoc__template_8h.html#a3ec6e82c05acab6b4bbd9530e8dc2268":[7,0,13,2,0,0,0,15,2],
+"corr__est__cc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,13,2,0,0,0,15,0],
+"corr__est__cc__pydoc__template_8h.html#a8991674c26e19b819a52781315b45795":[7,0,13,2,0,0,0,15,8],
+"corr__est__cc__pydoc__template_8h.html#a9ab5596f1cf8fffcc5ae91da85abaff2":[7,0,13,2,0,0,0,15,10],
+"corr__est__cc__pydoc__template_8h.html#a9fc047a3239e7128066face67a72ed59":[7,0,13,2,0,0,0,15,9],
+"corr__est__cc__pydoc__template_8h.html#ac17db1336ff99bfbf57e0e69e5437ce9":[7,0,13,2,0,0,0,15,5],
+"corr__est__cc__pydoc__template_8h.html#ad9ef5a43e910249c2793f2a631aba8d1":[7,0,13,2,0,0,0,15,1],
+"corr__est__cc__pydoc__template_8h.html#adf8f428ebb686d84d5f4b9029ebb9ce9":[7,0,13,2,0,0,0,15,3],
+"corr__est__cc__pydoc__template_8h.html#aeae62011ac74d8d5ebef390b15a35777":[7,0,13,2,0,0,0,15,7],
+"corr__est__cc__pydoc__template_8h.html#af967496832d12f2a5e5e83cecd371b4a":[7,0,13,2,0,0,0,15,6],
+"corr__est__cc__pydoc__template_8h_source.html":[7,0,13,2,0,0,0,15],
+"correctiq_8h.html":[7,0,9,1,0,0,34],
+"correctiq_8h_source.html":[7,0,9,1,0,0,34],
+"correctiq__auto_8h.html":[7,0,9,1,0,0,35],
+"correctiq__auto_8h_source.html":[7,0,9,1,0,0,35],
+"correctiq__auto__pydoc__template_8h.html":[7,0,9,2,0,0,0,31],
+"correctiq__auto__pydoc__template_8h.html#a0a6594019b519ea2d9c5e49aa2b47cfa":[7,0,9,2,0,0,0,31,7],
+"correctiq__auto__pydoc__template_8h.html#a209322ac31d5871fce8b7f646477f837":[7,0,9,2,0,0,0,31,6],
+"correctiq__auto__pydoc__template_8h.html#a6e05d728ef2cc1ca65e06d87371a1ce9":[7,0,9,2,0,0,0,31,8],
+"correctiq__auto__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,31,0],
+"correctiq__auto__pydoc__template_8h.html#a7692e33091ac80da2a948515968d2f7c":[7,0,9,2,0,0,0,31,2],
+"correctiq__auto__pydoc__template_8h.html#a8f0d3b661e847be0b484fb5fc42d802e":[7,0,9,2,0,0,0,31,5],
+"correctiq__auto__pydoc__template_8h.html#ab78a20ac83b020b146182e26f548d252":[7,0,9,2,0,0,0,31,3],
+"correctiq__auto__pydoc__template_8h.html#ad433508a8131834ceabf5d698bbbad0f":[7,0,9,2,0,0,0,31,1],
+"correctiq__auto__pydoc__template_8h.html#afdcf93cf28baf60e57463a8da67b7fcb":[7,0,9,2,0,0,0,31,4],
+"correctiq__auto__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,31],
+"correctiq__man_8h.html":[7,0,9,1,0,0,36],
+"correctiq__man_8h_source.html":[7,0,9,1,0,0,36],
+"correctiq__man__pydoc__template_8h.html":[7,0,9,2,0,0,0,32],
+"correctiq__man__pydoc__template_8h.html#a39ebbc4b2980b98f75a8955887672b31":[7,0,9,2,0,0,0,32,4],
+"correctiq__man__pydoc__template_8h.html#a63e47c82389f554891f9587fae070162":[7,0,9,2,0,0,0,32,3],
+"correctiq__man__pydoc__template_8h.html#a7341971bc4d8835826bc8deb061aa606":[7,0,9,2,0,0,0,32,5]
 };
