@@ -1,66 +1,5 @@
 var NAVTREEINDEX67 =
 {
-"pfb__clock__sync__ccf__pydoc__template_8h.html#aefd695e2a65ac47dd95504f8810d78c0":[7,0,13,2,0,0,0,72,3],
-"pfb__clock__sync__ccf__pydoc__template_8h.html#afe1c9916c69b6a2e1c99f01ddb67b38e":[7,0,13,2,0,0,0,72,11],
-"pfb__clock__sync__ccf__pydoc__template_8h_source.html":[7,0,13,2,0,0,0,72],
-"pfb__clock__sync__fff_8h.html":[7,0,13,1,0,0,76],
-"pfb__clock__sync__fff_8h_source.html":[7,0,13,1,0,0,76],
-"pfb__clock__sync__fff__pydoc__template_8h.html":[7,0,13,2,0,0,0,73],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a1b705a58bccb1a5f8747c15a080d1cdf":[7,0,13,2,0,0,0,73,16],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a1bc32d80ce86d2c3e575544c316db519":[7,0,13,2,0,0,0,73,11],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a2a9b06e2fbf6b2fd44b2d20d88139387":[7,0,13,2,0,0,0,73,7],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a2cc9fde0dd06ffa933cbc827ae3046a5":[7,0,13,2,0,0,0,73,17],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a40297ead8c6bb5dff0aed7c90bdccd5c":[7,0,13,2,0,0,0,73,13],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a405de58a2d62c036694b92ea45a20a47":[7,0,13,2,0,0,0,73,5],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a4947830272f45e6416dd0fd23db6ff8f":[7,0,13,2,0,0,0,73,21],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a625ce7ceabf6de9db78a0d1fa17866e6":[7,0,13,2,0,0,0,73,14],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a6d7533648d64e96b18343305e2376340":[7,0,13,2,0,0,0,73,3],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a6e41a64d3a6f993227f1d9b349dc53b0":[7,0,13,2,0,0,0,73,4],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,13,2,0,0,0,73,0],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a897af90163741dfe54a78e79fb98ced4":[7,0,13,2,0,0,0,73,9],
-"pfb__clock__sync__fff__pydoc__template_8h.html#a8a0f483f29abcebd2e9b04dc590a6cd3":[7,0,13,2,0,0,0,73,18],
-"pfb__clock__sync__fff__pydoc__template_8h.html#aa162b5e080d4de2d354227f08e2e6abb":[7,0,13,2,0,0,0,73,2],
-"pfb__clock__sync__fff__pydoc__template_8h.html#abc5f4f723c54d4c07944f27c026c0f0c":[7,0,13,2,0,0,0,73,8],
-"pfb__clock__sync__fff__pydoc__template_8h.html#abf118facea67d0910accf84e40246a6e":[7,0,13,2,0,0,0,73,19],
-"pfb__clock__sync__fff__pydoc__template_8h.html#ac1c1681b77f861bd05ac81070f9392d7":[7,0,13,2,0,0,0,73,10],
-"pfb__clock__sync__fff__pydoc__template_8h.html#ace4b28fb1e068807040a6abc287c9d3a":[7,0,13,2,0,0,0,73,15],
-"pfb__clock__sync__fff__pydoc__template_8h.html#acfc0d6155419872618afd92047f1dfa3":[7,0,13,2,0,0,0,73,1],
-"pfb__clock__sync__fff__pydoc__template_8h.html#ad024a5a22d920dac7af945b629c048d1":[7,0,13,2,0,0,0,73,22],
-"pfb__clock__sync__fff__pydoc__template_8h.html#ad134bfa9476b10e7edf540b5a27ce828":[7,0,13,2,0,0,0,73,20],
-"pfb__clock__sync__fff__pydoc__template_8h.html#adaeb1cb20236442eeee88c1c10a0191c":[7,0,13,2,0,0,0,73,12],
-"pfb__clock__sync__fff__pydoc__template_8h.html#af0c792985549da4aba4147dccf01c4b8":[7,0,13,2,0,0,0,73,6],
-"pfb__clock__sync__fff__pydoc__template_8h_source.html":[7,0,13,2,0,0,0,73],
-"pfb__decimator__ccf_8h.html":[7,0,21,1,0,0,37],
-"pfb__decimator__ccf_8h_source.html":[7,0,21,1,0,0,37],
-"pfb__decimator__ccf__pydoc__template_8h.html":[7,0,21,2,0,0,0,34],
-"pfb__decimator__ccf__pydoc__template_8h.html#a21abd7a95703589e1de4fcc9c4b9ef4d":[7,0,21,2,0,0,0,34,4],
-"pfb__decimator__ccf__pydoc__template_8h.html#a6e00608f3f538da4a72d0e2c311f0ff3":[7,0,21,2,0,0,0,34,7],
-"pfb__decimator__ccf__pydoc__template_8h.html#a73a41a32c09e85bfcfd99b453e8cff6b":[7,0,21,2,0,0,0,34,1],
-"pfb__decimator__ccf__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,21,2,0,0,0,34,0],
-"pfb__decimator__ccf__pydoc__template_8h.html#a9392d34d5bc17fbd48f3c5bfc9a7dc31":[7,0,21,2,0,0,0,34,2],
-"pfb__decimator__ccf__pydoc__template_8h.html#ab204a2ea5c94a08c7d6df195d87ac80c":[7,0,21,2,0,0,0,34,5],
-"pfb__decimator__ccf__pydoc__template_8h.html#ad856a19fec6bbec2742beea5a7fc8f75":[7,0,21,2,0,0,0,34,6],
-"pfb__decimator__ccf__pydoc__template_8h.html#adbe981692c1b2f6d7a387eb72b3f5d39":[7,0,21,2,0,0,0,34,3],
-"pfb__decimator__ccf__pydoc__template_8h.html#ae07b289ecf5249f4845d774b49487801":[7,0,21,2,0,0,0,34,8],
-"pfb__decimator__ccf__pydoc__template_8h_source.html":[7,0,21,2,0,0,0,34],
-"pfb__interpolator__ccf_8h.html":[7,0,21,1,0,0,38],
-"pfb__interpolator__ccf_8h_source.html":[7,0,21,1,0,0,38],
-"pfb__interpolator__ccf__pydoc__template_8h.html":[7,0,21,2,0,0,0,35],
-"pfb__interpolator__ccf__pydoc__template_8h.html#a1fec8a19c4854ee3a66fb2101e979746":[7,0,21,2,0,0,0,35,6],
-"pfb__interpolator__ccf__pydoc__template_8h.html#a389e83a433f264cc342c2afa84d2cd2e":[7,0,21,2,0,0,0,35,3],
-"pfb__interpolator__ccf__pydoc__template_8h.html#a69f4b70122c6f4989eb02af275d130cf":[7,0,21,2,0,0,0,35,4],
-"pfb__interpolator__ccf__pydoc__template_8h.html#a6b6e62a362a8f7461e9b874150fb6b24":[7,0,21,2,0,0,0,35,2],
-"pfb__interpolator__ccf__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,21,2,0,0,0,35,0],
-"pfb__interpolator__ccf__pydoc__template_8h.html#acb913dfbd4db313de3f6a50981f8b0ea":[7,0,21,2,0,0,0,35,5],
-"pfb__interpolator__ccf__pydoc__template_8h.html#ad56e245a1a127b3d41810a91fce99836":[7,0,21,2,0,0,0,35,1],
-"pfb__interpolator__ccf__pydoc__template_8h.html#ae2a1e0cf77ef730d49cf739b1a81469e":[7,0,21,2,0,0,0,35,7],
-"pfb__interpolator__ccf__pydoc__template_8h_source.html":[7,0,21,2,0,0,0,35],
-"pfb__synthesizer__ccf_8h.html":[7,0,21,1,0,0,39],
-"pfb__synthesizer__ccf_8h_source.html":[7,0,21,1,0,0,39],
-"pfb__synthesizer__ccf__pydoc__template_8h.html":[7,0,21,2,0,0,0,36],
-"pfb__synthesizer__ccf__pydoc__template_8h.html#a1b9ea6eb0579e3f509feb76957e5ec02":[7,0,21,2,0,0,0,36,5],
-"pfb__synthesizer__ccf__pydoc__template_8h.html#a32be2dd0880a5b81ebf2f316de600ad6":[7,0,21,2,0,0,0,36,1],
-"pfb__synthesizer__ccf__pydoc__template_8h.html#a373879d2f15f24fb72860219a0e317fe":[7,0,21,2,0,0,0,36,6],
 "pfb__synthesizer__ccf__pydoc__template_8h.html#a4ffc7528d08939b3c6652c578965bad5":[7,0,21,2,0,0,0,36,3],
 "pfb__synthesizer__ccf__pydoc__template_8h.html#a6731418e64e123fdfc8a7dbce4d28e36":[7,0,21,2,0,0,0,36,4],
 "pfb__synthesizer__ccf__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,21,2,0,0,0,36,0],
@@ -249,5 +188,66 @@ var NAVTREEINDEX67 =
 "pmt__pydoc__template_8h.html#a2d760bf07e44450b5c6c0cace877bc91":[7,0,3,1,1,0,0,1,206],
 "pmt__pydoc__template_8h.html#a2da44031789ee1dbd382d23ca49c7991":[7,0,3,1,1,0,0,1,104],
 "pmt__pydoc__template_8h.html#a2dabd6b4ffbf7f90474e07404f33a159":[7,0,3,1,1,0,0,1,77],
-"pmt__pydoc__template_8h.html#a2dea0cee6121771b74d0fd34dffc980f":[7,0,3,1,1,0,0,1,100]
+"pmt__pydoc__template_8h.html#a2dea0cee6121771b74d0fd34dffc980f":[7,0,3,1,1,0,0,1,100],
+"pmt__pydoc__template_8h.html#a2e4bc543fe4edf43a9fb443d9a0a8f5e":[7,0,3,1,1,0,0,1,42],
+"pmt__pydoc__template_8h.html#a2e607e16e6e85f2f9b1587909841debc":[7,0,3,1,1,0,0,1,146],
+"pmt__pydoc__template_8h.html#a2e972576b7af59553507af5d1ecd32be":[7,0,3,1,1,0,0,1,218],
+"pmt__pydoc__template_8h.html#a2f3f5f8668e722f4f0c85dcd6bf4d34c":[7,0,3,1,1,0,0,1,158],
+"pmt__pydoc__template_8h.html#a2fef6c7f605809d8f5467cac94d431a1":[7,0,3,1,1,0,0,1,34],
+"pmt__pydoc__template_8h.html#a30438eb7620cf0cf44b91b965a3b82a9":[7,0,3,1,1,0,0,1,125],
+"pmt__pydoc__template_8h.html#a30d09b41096dd5450ca512b247024927":[7,0,3,1,1,0,0,1,84],
+"pmt__pydoc__template_8h.html#a324166cf03f3912a23e290a2b14a096e":[7,0,3,1,1,0,0,1,68],
+"pmt__pydoc__template_8h.html#a341e9f7ad5802cc42bb1964336178f00":[7,0,3,1,1,0,0,1,228],
+"pmt__pydoc__template_8h.html#a34793f279f4d9fef7c0e07ef4489a4a6":[7,0,3,1,1,0,0,1,136],
+"pmt__pydoc__template_8h.html#a352aacc7c85436ffe6aff0208ad2a16f":[7,0,3,1,1,0,0,1,65],
+"pmt__pydoc__template_8h.html#a361be93d0629aa34b5fa7b97d4758bbb":[7,0,3,1,1,0,0,1,123],
+"pmt__pydoc__template_8h.html#a3a7048db9c4a7ca492602f79bceb8c86":[7,0,3,1,1,0,0,1,20],
+"pmt__pydoc__template_8h.html#a3b96effe4599e0b92c9b12af9772390d":[7,0,3,1,1,0,0,1,5],
+"pmt__pydoc__template_8h.html#a3c8e192b2186533ad0a721c839d5e74a":[7,0,3,1,1,0,0,1,70],
+"pmt__pydoc__template_8h.html#a3d5a241b8d8f49e09e62cd719a625171":[7,0,3,1,1,0,0,1,184],
+"pmt__pydoc__template_8h.html#a40691a68fcfdd5cc579627dcba5520eb":[7,0,3,1,1,0,0,1,61],
+"pmt__pydoc__template_8h.html#a407abb4349637af5741c213e7be5a94c":[7,0,3,1,1,0,0,1,109],
+"pmt__pydoc__template_8h.html#a4127089e0247b4189c3e4acaf9f67937":[7,0,3,1,1,0,0,1,163],
+"pmt__pydoc__template_8h.html#a438ed388bebd8228079945cf56ca60f9":[7,0,3,1,1,0,0,1,195],
+"pmt__pydoc__template_8h.html#a441315d3432b3d277ae2854c3d730b42":[7,0,3,1,1,0,0,1,23],
+"pmt__pydoc__template_8h.html#a44169cce34d5e54191e658a1a0c64ddb":[7,0,3,1,1,0,0,1,72],
+"pmt__pydoc__template_8h.html#a468bff6e80c23bf2e06beb07bad61b89":[7,0,3,1,1,0,0,1,97],
+"pmt__pydoc__template_8h.html#a471069796c4e0f9a9cfda1a406970eae":[7,0,3,1,1,0,0,1,37],
+"pmt__pydoc__template_8h.html#a476396060cc0d4c8c350857d98ce302c":[7,0,3,1,1,0,0,1,172],
+"pmt__pydoc__template_8h.html#a48e1c308b52cd113b3a8501ab23718da":[7,0,3,1,1,0,0,1,22],
+"pmt__pydoc__template_8h.html#a492e961ad9525c25d1940933ba69e45f":[7,0,3,1,1,0,0,1,188],
+"pmt__pydoc__template_8h.html#a4c53acfeb8992a55410c7f1174101622":[7,0,3,1,1,0,0,1,221],
+"pmt__pydoc__template_8h.html#a4cb137cc060397beb16cd57d61ab4da1":[7,0,3,1,1,0,0,1,203],
+"pmt__pydoc__template_8h.html#a4d7058398decea38130d6e2890afe396":[7,0,3,1,1,0,0,1,122],
+"pmt__pydoc__template_8h.html#a4e79a4f69ba35eef7a6ab5c66af9874c":[7,0,3,1,1,0,0,1,103],
+"pmt__pydoc__template_8h.html#a4efbab23c13c289a6d65f76876c57aa3":[7,0,3,1,1,0,0,1,216],
+"pmt__pydoc__template_8h.html#a52cc1331644b5e37c010cb31a42845bd":[7,0,3,1,1,0,0,1,277],
+"pmt__pydoc__template_8h.html#a53007cb57a0223850bb447b53796e449":[7,0,3,1,1,0,0,1,191],
+"pmt__pydoc__template_8h.html#a549ade5cb1ac7da65469235f680332c1":[7,0,3,1,1,0,0,1,275],
+"pmt__pydoc__template_8h.html#a5649b68ee6d7415d5a3a16805cb2ce6a":[7,0,3,1,1,0,0,1,129],
+"pmt__pydoc__template_8h.html#a58400b8d5b4d9f28daac6e0af3cb76f8":[7,0,3,1,1,0,0,1,197],
+"pmt__pydoc__template_8h.html#a59134bc5c23cf541c3795db48b062d93":[7,0,3,1,1,0,0,1,226],
+"pmt__pydoc__template_8h.html#a596b604cb448c0430cd589f3058b7ce2":[7,0,3,1,1,0,0,1,111],
+"pmt__pydoc__template_8h.html#a59a68abaec87d7a9c7f401c13cd21003":[7,0,3,1,1,0,0,1,19],
+"pmt__pydoc__template_8h.html#a5a324bc35a0c2e670c78b684f3d623ff":[7,0,3,1,1,0,0,1,78],
+"pmt__pydoc__template_8h.html#a5c2bcf40b493ea0c91963960c7028834":[7,0,3,1,1,0,0,1,15],
+"pmt__pydoc__template_8h.html#a5d10afa6c961d938767d0e887b5f95fd":[7,0,3,1,1,0,0,1,138],
+"pmt__pydoc__template_8h.html#a5d307e46bf9e8e04355b7a73eed552df":[7,0,3,1,1,0,0,1,128],
+"pmt__pydoc__template_8h.html#a5e27a2577fa3210cb56819296bbd8264":[7,0,3,1,1,0,0,1,179],
+"pmt__pydoc__template_8h.html#a5e6fd9741a80a53d525be65903ce7c56":[7,0,3,1,1,0,0,1,262],
+"pmt__pydoc__template_8h.html#a5f6816b814edfa467a8a00fbcfcdb5d3":[7,0,3,1,1,0,0,1,205],
+"pmt__pydoc__template_8h.html#a5fbcd547fce01e5001142bcb27e15135":[7,0,3,1,1,0,0,1,50],
+"pmt__pydoc__template_8h.html#a60515e2a0e76192b2205739238718152":[7,0,3,1,1,0,0,1,161],
+"pmt__pydoc__template_8h.html#a617eb43ddd586999e12bc92d66b85c14":[7,0,3,1,1,0,0,1,143],
+"pmt__pydoc__template_8h.html#a61a67351b8db99196fc4a74ef0600f70":[7,0,3,1,1,0,0,1,88],
+"pmt__pydoc__template_8h.html#a61db17a062257e4adea5e633b186fbdd":[7,0,3,1,1,0,0,1,162],
+"pmt__pydoc__template_8h.html#a61e5fa5a2d4edff9fff54f0af698c3a7":[7,0,3,1,1,0,0,1,202],
+"pmt__pydoc__template_8h.html#a62806f9fd79c50bfc8019fd66e502b32":[7,0,3,1,1,0,0,1,169],
+"pmt__pydoc__template_8h.html#a6320cb603811a969f58b0adfc270b2af":[7,0,3,1,1,0,0,1,208],
+"pmt__pydoc__template_8h.html#a63f8568e2ee593f248a565ea2b4bd39f":[7,0,3,1,1,0,0,1,220],
+"pmt__pydoc__template_8h.html#a64dfd75165165ed173abfa4580289d3c":[7,0,3,1,1,0,0,1,6],
+"pmt__pydoc__template_8h.html#a67198291a13447fa3e355fed4acb9f51":[7,0,3,1,1,0,0,1,48],
+"pmt__pydoc__template_8h.html#a6890e94cf4b6d2731f23f81a3cc5b532":[7,0,3,1,1,0,0,1,178],
+"pmt__pydoc__template_8h.html#a68cdd527ad018169f722437832c019dc":[7,0,3,1,1,0,0,1,117],
+"pmt__pydoc__template_8h.html#a6950be259dd6bfc851fe1ca6c3b427c6":[7,0,3,1,1,0,0,1,121]
 };
